@@ -1,2 +1,2 @@
 __version__ = "0.0.4"
-from pylaunch import *
+from launchpy import *
